/* Products */

INSERT INTO products (			/*  1 */
  name
) VALUES (
 'Debian 6.0 i686'
);

INSERT INTO products (			/*  2 */
  name
) VALUES (
 'Debian 6.0 x86_64'
);

INSERT INTO products (			/*  3 */
  name
) VALUES (
 'Debian 7.0 i686'
);

INSERT INTO products (			/*  4 */
  name
) VALUES (
 'Debian 7.0 x86_64'
);

INSERT INTO products (			/*  5 */
  name
) VALUES (
 'Debian 8.0 i686'
);

INSERT INTO products (			/*  6 */
  name
) VALUES (
 'Debian 8.0 x86_64'
);

INSERT INTO products (			/*  7 */
  name
) VALUES (
 'Ubuntu 10.04 i686'
);

INSERT INTO products (			/*  8 */
  name
) VALUES (
 'Ubuntu 10.04 x86_64'
);

INSERT INTO products (			/*  9 */
  name
) VALUES (
 'Ubuntu 10.10 i686'
);

INSERT INTO products (			/* 10 */
  name
) VALUES (
 'Ubuntu 10.10 x86_64'
);

INSERT INTO products (			/* 11 */
  name
) VALUES (
 'Ubuntu 11.04 i686'
);

INSERT INTO products (			/* 12 */
  name
) VALUES (
 'Ubuntu 11.04 x86_64'
);

INSERT INTO products (			/* 13 */
  name
) VALUES (
 'Ubuntu 11.10 i686'
);

INSERT INTO products (			/* 14 */
  name
) VALUES (
 'Ubuntu 11.10 x86_64'
);

INSERT INTO products (			/* 15 */
  name
) VALUES (
 'Ubuntu 12.04 i686'
);

INSERT INTO products (			/* 16 */
  name
) VALUES (
 'Ubuntu 12.04 x86_64'
);

INSERT INTO products (			/* 17 */
  name
) VALUES (
 'Ubuntu 12.10 i686'
);

INSERT INTO products (			/* 18 */
  name
) VALUES (
 'Ubuntu 12.10 x86_64'
);

INSERT INTO products (			/* 19 */
  name
) VALUES (
 'Ubuntu 13.04 i686'
);

INSERT INTO products (			/* 20 */
  name
) VALUES (
 'Ubuntu 13.04 x86_64'
);

INSERT INTO products (			/* 21 */
  name
) VALUES (
 'Android 4.1.1'
);

INSERT INTO products (			/* 22 */
  name
) VALUES (
 'Android 4.2.1'
);

INSERT INTO products (			/* 23 */
  name
) VALUES (
 'Ubuntu 13.10 i686'
);

INSERT INTO products (			/* 24 */
  name
) VALUES (
 'Ubuntu 13.10 x86_64'
);

INSERT INTO products (			/* 25 */
  name
) VALUES (
 'Debian 7.1 i686'
);

INSERT INTO products (			/* 26 */
  name
) VALUES (
 'Debian 7.1 x86_64'
);

INSERT INTO products (			/* 27 */
  name
) VALUES (
 'Debian 7.2 i686'
);

INSERT INTO products (			/* 28 */
  name
) VALUES (
 'Debian 7.2 x86_64'
);

INSERT INTO products (			/* 29 */
  name
) VALUES (
 'Android 4.1.2'
);

INSERT INTO products (			/* 30 */
  name
) VALUES (
 'Android 4.2.2'
);

INSERT INTO products (			/* 31 */
  name
) VALUES (
 'Android 4.3.1'
);

INSERT INTO products (			/* 32 */
  name
) VALUES (
 'Android 4.4'
);

INSERT INTO products (			/* 33 */
  name
) VALUES (
 'Android 4.4.1'
);

INSERT INTO products (			/* 34 */
  name
) VALUES (
 'Android 4.4.2'
);

INSERT INTO products (			/* 35 */
  name
) VALUES (
 'Ubuntu 14.04 i686'
);

INSERT INTO products (			/* 36 */
  name
) VALUES (
 'Ubuntu 14.04 x86_64'
);

INSERT INTO products (			/* 37 */
  name
) VALUES (
 'Debian 7.3 i686'
);

INSERT INTO products (			/* 38 */
  name
) VALUES (
 'Debian 7.3 x86_64'
);

INSERT INTO products (			/* 39 */
  name
) VALUES (
 'Debian 7.4 i686'
);

INSERT INTO products (			/* 40 */
  name
) VALUES (
 'Debian 7.4 x86_64'
);

INSERT INTO products (			/* 41 */
  name
) VALUES (
 'Debian 7.5 i686'
);

INSERT INTO products (			/* 42 */
  name
) VALUES (
 'Debian 7.5 x86_64'
);

INSERT INTO products (			/* 43 */
  name
) VALUES (
 'Debian 7.0 armv6l'
);

INSERT INTO products (			/* 44 */
  name
) VALUES (
 'Debian 7.1 armv6l'
);

INSERT INTO products (			/* 45 */
  name
) VALUES (
 'Debian 7.2 armv6l'
);

INSERT INTO products (			/* 46 */
  name
) VALUES (
 'Debian 7.3 armv6l'
);

INSERT INTO products (			/* 47 */
  name
) VALUES (
 'Debian 7.4 armv6l'
);

INSERT INTO products (			/* 48 */
  name
) VALUES (
 'Debian 7.5 armv6l'
);

INSERT INTO products (			/* 49 */
  name
) VALUES (
 'Android 4.3'
);

INSERT INTO products (			/* 50 */
  name
) VALUES (
 'Android 4.4.3'
);

INSERT INTO products (			/* 51 */
  name
) VALUES (
 'Android 4.4.4'
);

INSERT INTO products (			/* 52 */
  name
) VALUES (
 'Debian 7.6 i686'
);

INSERT INTO products (			/* 53 */
  name
) VALUES (
 'Debian 7.6 x86_64'
);
INSERT INTO products (			/* 54 */
  name
) VALUES (
 'Debian 7.6 armv6l'
);

INSERT INTO products (			/* 55 */
  name
) VALUES (
 'Debian 7.7 i686'
);

INSERT INTO products (			/* 56 */
  name
) VALUES (
 'Debian 7.7 x86_64'
);
INSERT INTO products (			/* 57 */
  name
) VALUES (
 'Debian 7.7 armv6l'
);

INSERT INTO products (			/* 58 */
  name
) VALUES (
 'Debian 7.8 i686'
);

INSERT INTO products (			/* 59 */
  name
) VALUES (
 'Debian 7.8 x86_64'
);

INSERT INTO products (			/* 60 */
  name
) VALUES (
 'Debian 7.8 armv6l'
);

INSERT INTO products (			/* 61 */
  name
) VALUES (
 'Ubuntu 14.10 i686'
);

INSERT INTO products (			/* 62 */
  name
) VALUES (
 'Ubuntu 14.10 x86_64'
);

INSERT INTO products (			/* 63 */
  name
) VALUES (
 'Android 5.0'
);

INSERT INTO products (			/* 64 */
  name
) VALUES (
 'Android 5.0.1'
);

INSERT INTO products (			/* 65 */
  name
) VALUES (
 'Debian 7.8 armv7l'
);

/* Directories */

INSERT INTO directories (		/*  1 */
  path
) VALUES (
 '/bin'
);

INSERT INTO directories (		/*  2 */
  path
) VALUES (
 '/etc'
);

INSERT INTO directories (		/*  3 */
  path
) VALUES (
 '/lib'
);

INSERT INTO directories (		/*  4 */
  path
) VALUES (
 '/lib/i386-linux-gnu'
);

INSERT INTO directories (		/*  5 */
  path
) VALUES (
 '/lib/x86_64-linux-gnu'
);

INSERT INTO directories (		/*  6 */
  path
) VALUES (
 '/lib/xtables'
);

INSERT INTO directories (		/*  7 */
  path
) VALUES (
 '/sbin'
);

INSERT INTO directories (		/*  8 */
  path
) VALUES (
 '/usr/bin'
);

INSERT INTO directories (		/*  9 */
  path
) VALUES (
 '/usr/lib'
);

INSERT INTO directories (		/* 10 */
  path
) VALUES (
 '/usr/lib/i386-linux-gnu'
);

INSERT INTO directories (		/* 11 */
  path
) VALUES (
 '/usr/lib/x86_64-linux-gnu'
);

INSERT INTO directories (		/* 12 */
  path
) VALUES (
 '/usr/sbin'
);

INSERT INTO directories (		/* 13 */
  path
) VALUES (
 '/system/bin'
);

INSERT INTO directories (		/* 14 */
  path
) VALUES (
 '/system/lib'
);

/* Files */

INSERT INTO files (				/*  1 */
  name, dir
) VALUES (
 'libcrypto.so.1.0.0', 5
);

INSERT INTO files (				/*  2 */
  name, dir
) VALUES (
 'libcrypto.so.1.0.0', 11
);

INSERT INTO files (				/*  3 */
  name, dir
) VALUES (
 'libssl.so.1.0.0', 5
);

INSERT INTO files (				/*  4 */
  name, dir
) VALUES (
 'libssl.so.1.0.0', 11
);

INSERT INTO files (				/*  5 */
  name, dir
) VALUES (
  'openssl', 8
);

INSERT INTO files (				/*  6 */
  name, dir
) VALUES (
  'tnc_config', 2
);

/* Algorithms */

INSERT INTO algorithms (
  id, name
) VALUES (
  32768, 'SHA1' 
);

INSERT INTO algorithms (
  id, name
) VALUES (
  16384, 'SHA256' 
);

INSERT INTO algorithms (
  id, name
) VALUES (
  8192, 'SHA384' 
);

/* File Hashes */

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 2, 32768, X'6c6f8e12f6cbfba612e780374c4cdcd40f20968a'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 2, 16384, X'dbcecd19d59310183cf5c31ddee29e8d7bec64d3f9583aad074330a1b3024b07'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 2, 8192, X'197c5385e5853003188833d4f991136c1b0875fa416a60b1159f64e57e457b3184762c884a802a2bda194c058e3bd953'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 4, 32768, X'3ad204f99eb7262efab79cfca02628870ea76361'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 4, 16384, X'3a2170aad92fdd58b55e0e199822bc873cf587b2d1eb1ed7ed8dcea97ae86376'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 4, 8192, X'f778076baa876b5e4b502494a3db081fb09dd870dee6991d54104a74b7e009c58fe261db5ffd13c11e08ef0cefcfa59f'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 5, 32768, X'ecd9c7076cc0572724c7a67db7f19c2831e0445f'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 5, 16384, X'28f3ea5afd34444c8232ea75003131e294a0c9b847de300e4b205d38c1a41305'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  28, 5, 8192, X'51921a8b9322f2d3f06d55002ff40a79da67e70cb563b2a50977642d603dfac2ccbb68b3d32a8bb350769b75d6254208'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 1, 32768, X'd9309b9e45928239d7a7b18711e690792632cce4'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 1, 16384, X'dbfa1856d278d8707c4989b30dd065b4bcd309908f0f2e6e66ff2aa83ff93f59'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 1, 8192, X'fb8d027f03bb5ebb47741ed247eb9e174127b714d20229885feb37e0979aeb14a1b74020cded891d680441093625729c'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 3, 32768, X'3715f2f94016a91fab5bbc503f0f1d43c5a9fc2b'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 3, 16384, X'c03a5296b5decb87b01517f9927a8b2349dfb29ff9f5ba084f994c155ca5d4be'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 3, 8192, X'b8bc345f56115235cc6091f61e312ce43ea54a5b99e7295002ae7b415fd35e06ec4c731ab70ad00d784bb53a318a2fa0'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 5, 32768, X'e59602f4edf24c1b36199588886d06665d4adcd7'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 5, 16384, X'090e1b77bda7fe665e498c6b5e09dbb7ddc5cfe57f213de48f4fb6736484f500'
);

INSERT INTO file_hashes (
  product, file, algo, hash
) VALUES (
  18, 5, 8192, X'7cbdb4612a13443dba910ecdef5161f2213e52c9b4a2eef14bcee5d287e9df931cd022e9e9715518ad9c9b6e3384a668'
);

/* Packages */

INSERT INTO packages (			/*  1 */
  name
) VALUES (
 'libssl-dev'
);

INSERT INTO packages (			/*  2 */
  name
) VALUES (
 'libssl1.0.0'
);

INSERT INTO packages (			/*  3 */
  name
) VALUES (
 'libssl1.0.0-dbg'
);

INSERT INTO packages (			/*  4 */
  name
) VALUES (
 'openssl'
);

/* Versions */

INSERT INTO versions (
  package, product, release, time
) VALUES (
  1, 28, '1.0.1e-2', 1366531494
);

INSERT INTO versions (
  package, product, release, time
) VALUES (
  2, 28, '1.0.1e-2', 1366531494
);

INSERT INTO versions (
  package, product, release, time
) VALUES (
  3, 28, '1.0.1e-2', 1366531494
);

INSERT INTO versions (
  package, product, release, time
) VALUES (
  4, 28, '1.0.1e-2', 1366531494
);

/* Components */

INSERT INTO components (
  vendor_id, name, qualifier, label
) VALUES (
  36906, 1, 33, 'G'  /* ITA TGRUB */
);

INSERT INTO components (
  vendor_id, name, qualifier, label
) VALUES (
  36906, 2, 33, 'T'  /* ITA TBOOT */
);

INSERT INTO components (
  vendor_id, name, qualifier, label
) VALUES (
  36906, 3, 33, 'B' /* ITA IMA - Trusted Platform */
);

INSERT INTO components (
  vendor_id, name, qualifier, label
) VALUES (
  36906, 3, 34, 'I' /* ITA IMA - Operating System */
);

/* Groups */

INSERT INTO groups (			/*  1 */
  name
) VALUES (
  'Default'
);

INSERT INTO groups (			/*  2 */
  name, parent
) VALUES (
  'Linux', 1
);

INSERT INTO groups (			/*  3 */
  name, parent
) VALUES (
  'Android', 1
);

INSERT INTO groups (			/*  4 */
  name, parent
) VALUES (
  'Debian i686', 2
);

INSERT INTO groups (			/*  5 */
  name, parent
) VALUES (
  'Debian x86_64', 2
);

INSERT INTO groups (			/*  6 */
  name, parent
) VALUES (
  'Ubuntu i686', 2
);

INSERT INTO groups (			/*  7 */
  name, parent
) VALUES (
  'Ubuntu x86_64', 2
);

INSERT INTO groups (			/*  8 */
  name
) VALUES (
  'Reference'
);

INSERT INTO groups (			/*  9 */
  name, parent
) VALUES (
  'Ref. Android', 8
);

INSERT INTO groups (			/* 10 */
  name, parent
) VALUES (
  'Ref. Linux', 8
);

INSERT INTO groups (            /* 11 */
  name
) VALUES (
  'TPM BIOS'
);

INSERT INTO groups (            /* 12 */
  name
) VALUES (
  'TPM IMA'
);

INSERT INTO groups (            /* 13 */
  name
) VALUES (
  'TPM BIOS/IMA'
);

INSERT INTO groups (			/* 14 */
  name, parent
) VALUES (
  'Debian armv6l', 2
);

INSERT INTO groups (			/* 15 */
  name, parent
) VALUES (
  'Debian armv7l', 2
);

INSERT INTO groups (            /* 16 */
  name
) VALUES (
  'TPM TBOOT'
);

/* Default Product Groups */

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 1
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 3
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 5
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 25
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 27
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 37
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 39
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 41
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 52
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 55
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  4, 58
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 2
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 4
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 6
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 26
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 28
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 38
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 40
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 42
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 53
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 56
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  5, 59
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 9
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 11
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 13
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 15
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 17
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 19
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 23
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 35
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  6, 61
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 8
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 10
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 12
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 14
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 16
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 18
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 20
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 24
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 36
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  7, 62
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 21
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 22
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 29
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 30
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 31
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 32
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 33
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 34
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 49
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 50
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 63
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 64
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  3, 51
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 43
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 44
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 45
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 46
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 47
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 48
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 54
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 57
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  14, 60
);

INSERT INTO groups_product_defaults (
  group_id, product_id
) VALUES (
  15, 65
);

/* Policies */

INSERT INTO policies (			/*  1 */
  type, name, rec_fail, rec_noresult
) VALUES (
  1, 'Installed Packages', 2, 2
);

INSERT INTO policies (			/*  2 */
  type, name, rec_fail, rec_noresult
) VALUES (
  2, 'Unknown Source', 2, 2
);

INSERT INTO policies (			/*  3 */
  type, name, rec_fail, rec_noresult
) VALUES (
  3, 'IP Forwarding Enabled',  1, 1
);

INSERT INTO policies (			/*  4 */
  type, name, rec_fail, rec_noresult
) VALUES (
  4, 'Default Factory Password Enabled', 1, 1
);

INSERT INTO policies (			/*  5 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  6, 'Measure /lib/x86_64-linux-gnu/libcrypto.so.1.0.0', 1, 2, 2
);

INSERT INTO policies (			/*  6 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  6, 'Measure /lib/x86_64-linux-gnu/libssl.so.1.0.0', 3, 2, 2
);

INSERT INTO policies (			/*  7 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  6, 'Measure /usr/bin/openssl', 5, 2, 2
);

INSERT INTO policies (			/*  8 */
  type, name, rec_fail, rec_noresult
) VALUES (
  11, 'No Open TCP Ports', 1, 1
);

INSERT INTO policies (			/*  9 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  13, 'Open UDP Ports', '500 4500 10000-65000', 1, 1
);

INSERT INTO policies (			/* 10 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  7, 'Metadata of /etc/tnc_config', 6, 0, 0
);

INSERT INTO policies (			/* 11 */
  type, name, dir, rec_fail, rec_noresult
) VALUES (
  8, 'Get /bin', 1, 0, 0
);

INSERT INTO policies (			/*  12 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  6, 'Measure /usr/lib/x86_64-linux-gnu/libcrypto.so.1.0.0', 2, 2, 2
);

INSERT INTO policies (			/* 13 */
  type, name, file, rec_fail, rec_noresult
) VALUES (
  6, 'Measure /usr/lib/x86_64-linux-gnu/libssl.so.1.0.0', 4, 2, 2
);

INSERT INTO policies (			/* 14 */
  type, name, dir, rec_fail, rec_noresult
) VALUES (
  8, 'Get /system/bin', 13, 0, 0
);

INSERT INTO policies (			/* 15 */
  type, name, dir, rec_fail, rec_noresult
) VALUES (
  8, 'Get /system/lib', 14, 0, 0
);

INSERT INTO policies (          /* 16 */
  type, name, dir, rec_fail, rec_noresult
) VALUES (
  9, 'Measure /bin', 1, 2, 2
);

INSERT INTO policies (			/* 17 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  15, 'SWID Tag IDs', 'R', 2, 2
);

INSERT INTO policies (			/* 18 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  15, 'SWID Tags', '', 2, 2
);

INSERT INTO policies (          /* 19 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  16, 'TPM BIOS Measurements', 'B', 2, 2
);

INSERT INTO policies (          /* 20 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  16, 'TPM IMA Measurements', 'I', 2, 2
);

INSERT INTO policies (          /* 21 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  16, 'TPM BIOS/IMA Measurements', 'BI', 2, 2
);

INSERT INTO policies (          /* 22 */
  type, name, argument, rec_fail, rec_noresult
) VALUES (
  16, 'TPM TBOOT Measurements', 'T', 2, 2
);

/* Enforcements */

INSERT INTO enforcements (		/*  1 */
  policy, group_id, max_age
) VALUES (
  1, 1, 86400
);

INSERT INTO enforcements (		/*  2 */
  policy, group_id, max_age
) VALUES (
  2, 3, 0
);

INSERT INTO enforcements (		/*  3 */
  policy, group_id, max_age
) VALUES (
  3, 2, 0
);

INSERT INTO enforcements (		/*  4 */
  policy, group_id, max_age
) VALUES (
  5, 7, 86400
);

INSERT INTO enforcements (		/*  5 */
  policy, group_id, max_age
) VALUES (
  6, 7, 86400
);

INSERT INTO enforcements (		/*  6 */
  policy, group_id, max_age
) VALUES (
  7, 2, 86400
);

INSERT INTO enforcements (		/*  7 */
  policy, group_id, max_age
) VALUES (
  8, 1, 60
);

INSERT INTO enforcements (		/*  8 */
  policy, group_id, max_age
) VALUES (
  9, 1, 60
);

INSERT INTO enforcements (		/*  9 */
  policy, group_id, max_age
) VALUES (
  10, 2, 60
);

INSERT INTO enforcements (		/* 10 */
  policy, group_id, max_age
) VALUES (
  11, 10, 86400
);

INSERT INTO enforcements (		/* 11 */
  policy, group_id, max_age
) VALUES (
  12, 5, 86400
);

INSERT INTO enforcements (		/* 12 */
  policy, group_id, max_age
) VALUES (
  13, 5, 86400
);

INSERT INTO enforcements (		/* 13 */
  policy, group_id, max_age
) VALUES (
  14, 9, 0
);

INSERT INTO enforcements (		/* 14 */
  policy, group_id, max_age
) VALUES (
  15, 9, 0
);

INSERT INTO enforcements (      /* 15 */
  policy, group_id, max_age
) VALUES (
  19, 11, 60
);

INSERT INTO enforcements (      /* 16 */
  policy, group_id, max_age
) VALUES (
  20, 12, 60
);

INSERT INTO enforcements (      /* 17 */
  policy, group_id, max_age
) VALUES (
  21, 13, 60
);

INSERT INTO enforcements (      /* 18 */
  policy, group_id, max_age
) VALUES (
  22, 16, 60
);

/* swid_entities */

INSERT INTO "swid_entities" (		/*  1 */
  "name", "regid"
) VALUES (
  'strongSwan Project', 'regid.2004-03.org.strongswan'
);

INSERT INTO swid_entities (			/*  2 */
  "name", "regid"
) VALUES (
  'Adobe Systems Inc.', 'regid.1986-12.com.adobe'
);

INSERT INTO swid_entities (			/*  3 */
  "name", "regid"
) VALUES (
  'Microsoft Corporation', 'regid.1991-06.com.microsoft'
);

INSERT INTO swid_entities (			/*  4 */
  "name", "regid"
) VALUES (
  'Ubuntu Project', 'regid.2004-05.com.ubuntu'
);

INSERT INTO swid_entities (			/*  5 */
  "name", "regid"
) VALUES (
  'Apache Software Foundation', 'regid.1995-04.org.apache'
);

INSERT INTO swid_entities (			/*  6 */
  "name", "regid"
) VALUES (
  'Debian Project', 'regid.1999-03.org.debian'
);

INSERT INTO swid_entities (			/*  7 */
  "name", "regid"
) VALUES (
  'Internet Systems Consortium', 'regid.1994-04.org.isc'
);

INSERT INTO swid_entities (			/*  8 */
  "name", "regid"
) VALUES (
  'OpenSSL Project', 'regid.1998-12.org.openssl'
);

INSERT INTO swid_entities (			/*  9 */
  "name", "regid"
) VALUES (
  'Samba Project', 'regid.1998-01.org.samba'
);

INSERT INTO swid_entities (			/* 10 */
  "name", "regid"
) VALUES (
  'SQLite Project', 'regid.2002-08.org.sqlite'
);
